<?php

/**
 * Settings page callback.
 */
function shutdown_settings_form() {
  $form['shutdown_enable'] = array(
    '#type' => 'checkbox',
    '#title' => t('Shut down website?'),
    '#default_value' => variable_get('shutdown_enable', 0),
    '#description' => t('If you enable this option, your website will be closed for all visitors except those who have adequate permission.'),
  );
  $form['shutdown_redirect_page'] = array(
    '#type' => 'textfield',
    '#title' => t('Redirect page'),
    '#default_value' => variable_get('shutdown_redirect_page', ''),
    '#description' => t('Specify the page to redirect to. This could be a Drupal internal path, an URL or a file relative to drupal directory.'),
  );
//  $form['shutdown_http_response_code'] = array(
//    '#type' => 'select',
//    '#title' => t('HTTP response code'),
//    '#options' => array(
//      '503' => t('503 Service Unavailable'),
//      '403' => t('403 Forbidden (default)'),
//      '301' => t('301 Moved Permanently'),
//      '307' => t('307 Temporary Redirect '),
//    ),
//    '#default_value' => variable_get('shutdown_http_response_code', '403'),
//  );
  $form['shutdown_excluded_paths'] = array(
    '#type' => 'textarea',
    '#title' => t('Paths to exclude'),
    '#default_value' => variable_get('shutdown_excluded_paths', ''),
    '#description' => t('Specify the paths that should remain accessible. One path per line.'),
  );

  return system_settings_form($form);
}

/**
 * Validate function for shutdown_settings_form().
 */
function shutdown_settings_form_validate($form, &$form_state) {
  $excluded_paths = explode(PHP_EOL, $form_state['values']['shutdown_excluded_paths']);
  $redirect_page = $form_state['values']['shutdown_redirect_page'];

  // In case website should be shut down, make sure redirect page is not empty.
  if ($form_state['values']['shutdown_enable'] && empty($redirect_page)) {
    form_set_error('shutdown_redirect_page', t('Please specify a redirect page'));
  }
  // If page is an external URL, make sure it is valid.
  else if (url_is_external($redirect_page)) {
    if (!valid_url($redirect_page)) {
      form_set_error('shutdown_redirect_page', t('%page is not valid.', array('%page' => $redirect_page)));
    }
  }
  // Make sure redirect page is not index.php to avoid infinite redirections.
  else if ($redirect_page == 'index.php') {
    form_set_error('shutdown_redirect_page', t('%page cannot be used for page redirection.', array('%page' => $redirect_page)));
  }
  // If page is an internal path, make sure it is in excluded paths to avoid
  // infinite redirections.
  else if (menu_get_item($redirect_page) && !in_array($redirect_page, $excluded_paths)) {
    form_set_error('shutdown_redirect_page', t('%page should be added to excluded paths in order to avoid infinte loops.', array('%page' => $redirect_page)));
  }
}
